==> webpdf-wsclient-10.0.1-sources.jar: net/webpdf/wsclient/schema/operation/ConverterTransformType.java <==

package net.webpdf.wsclient.schema.operation;

import jakarta.xml.bind.annotation.XmlAccessType;
import jakarta.xml.bind.annotation.XmlAccessorType;
import jakarta.xml.bind.annotation.XmlType;


/**
 * <pre>
 * &lt;?xml version="1.0" encoding="UTF-8"?&gt;&lt;p xmlns:p165541_="https://jakarta.ee/xml/ns/jaxb" xmlns:p356920_="urn:jaxb.jvnet.org:plugin:inheritance" xmlns:tns="http://schema.webpdf.de/1.0/operation" xmlns:xs="http://www.w3.org/2001/XMLSchema"&gt;This element defines a set of transformations to be applied to the document before further converter operations are performed. For example, an XSLT transformation could be applied to an XML document to transform it to HTML before converting that HTML content to a PDF document.&#13;
 *                     This element currently recognizes two forms of transformations:&#13;
 *                     &lt;ul&gt;&lt;li&gt;XSLT transformation - a generic transformation to any output format.&lt;/li&gt;&#13;
 *                         Optimally, the transformation creates a document format (such as HTML) that the downstream conversion can convert to a PDF document. The generic transformation can contain an arbitrary number of XSLT elements, defined as &lt;code&gt;&amp;lt;resources&amp;gt;&lt;/code&gt;, each of which is successively applied to the result of the preceding transformation.&#13;
 *                         &lt;li&gt;XInvoice transformation - XML data in XInvoice format (CII or UBL) transformed into a visual image by means of transformation.&lt;/li&gt;&lt;/ul&gt;&#13;
 *                     Normally, no further specification is necessary here, because a standard layout for the visual image of an X-invoice is stored on the server. However, if a different layout is to be used, this must be specified via the &lt;code&gt;&amp;lt;visualization&amp;gt;&lt;/code&gt; element. The file used there must be an XLST stylesheet, which creates the XInvoice data as HTML output.&#13;
 *                 &lt;/p&gt;
 * </pre>
 * 
 * <p>Java class for ConverterTransformType complex type</p>.
 * 
 * <p>The following schema fragment specifies the expected content contained within this class.</p>
 * 
 * <pre>{@code
 * <complexType name="ConverterTransformType">
 *   <complexContent>
 *     <restriction base="{http://www.w3.org/2001/XMLSchema}anyType">
 *       <choice>
 *         <element name="xslTransformation" type="{http://schema.webpdf.de/1.0/operation}XslTransformationType"/>
 *         <element name="xRechnung" type="{http://schema.webpdf.de/1.0/operation}XRechnungType"/>
 *       </choice>
 *     </restriction>
 *   </complexContent>
 * </complexType>
 * }</pre>
 * 
 * 
 */
@XmlAccessorType(XmlAccessType.FIELD)
@XmlType(name = "ConverterTransformType", propOrder = {
    "xslTransformation",
    "xRechnung"
})
public class ConverterTransformType {

    protected XslTransformationType xslTransformation;
    protected XRechnungType xRechnung;

    /**
     * Gets the value of the xslTransformation property.
     * 
     * @return
     *     possible object is
     *     {@link XslTransformationType }
     *     
     */
    public XslTransformationType getXslTransformation() {
        return xslTransformation;
    }

    /**
     * Sets the value of the xslTransformation property.
     * 
     * @param value
     *     allowed object is
     *     {@link XslTransformationType }
     *     
     */
    public void setXslTransformation(XslTransformationType value) {
        this.xslTransformation = value;
    }

    public boolean isSetXslTransformation() {
        return (this.xslTransformation!= null);
    }

    /**
     * Gets the value of the xRechnung property.
     * 
     * @return
     *     possible object is
     *     {@link XRechnungType }
     *     
     */
    public XRechnungType getXRechnung() {
        return xRechnung;
    }

    /**
     * Sets the value of the xRechnung property.
     * 
     * @param value
     *     allowed object is
     *     {@link XRechnungType }
     *     
     */
    public void setXRechnung(XRechnungType value) {
        this.xRechnung = value;
    }

    public boolean isSetXRechnung() {
        return (this.xRechnung!= null);
    }

}

==> webpdf-wsclient-10.0.2-sources.jar: net/webpdf/wsclient/schema/operation/ConverterTransformType.java <==

package net.webpdf.wsclient.schema.operation;

import jakarta.xml.bind.annotation.XmlAccessType;
import jakarta.xml.bind.annotation.XmlAccessorType;
import jakarta.xml.bind.annotation.XmlType;


/**
 * <pre>
 * &lt;?xml version="1.0" encoding="UTF-8"?&gt;&lt;p xmlns:p532746_="urn:jaxb.jvnet.org:plugin:inheritance" xmlns:p882137_="https://jakarta.ee/xml/ns/jaxb" xmlns:tns="http://schema.webpdf.de/1.0/operation" xmlns:xs="http://www.w3.org/2001/XMLSchema"&gt;This element defines a set of transformations to be applied to the document before further converter operations are performed. For example, an XSLT transformation could be applied to an XML document to transform it to HTML before converting that HTML content to a PDF document.&#13;
 *                     This element currently recognizes two forms of transformations:&#13;
 *                     &lt;ul&gt;&lt;li&gt;XSLT transformation - a generic transformation to any output format.&lt;/li&gt;&#13;
 *                         Optimally, the transformation creates a document format (such as HTML) that the downstream conversion can convert to a PDF document. The generic transformation can contain an arbitrary number of XSLT elements, defined as &lt;code&gt;&amp;lt;resources&amp;gt;&lt;/code&gt;, each of which is successively applied to the result of the preceding transformation.&#13;
 *                         &lt;li&gt;XInvoice transformation - XML data in XInvoice format (CII or UBL) transformed into a visual image by means of transformation.&lt;/li&gt;&lt;/ul&gt;&#13;
 *                     Normally, no further specification is necessary here, because a standard layout for the visual image of an X-invoice is stored on the server. However, if a different layout is to be used, this must be specified via the &lt;code&gt;&amp;lt;visualization&amp;gt;&lt;/code&gt; element. The file used there must be an XLST stylesheet, which creates the XInvoice data as HTML output.&#13;
 *                 &lt;/p&gt;
 * </pre>
 * 
 * <p>Java class for ConverterTransformType complex type</p>.
 * 
 * <p>The following schema fragment specifies the expected content contained within this class.</p>
 * 
 * <pre>{@code
 * <complexType name="ConverterTransformType">
 *   <complexContent>
 *     <restriction base="{http://www.w3.org/2001/XMLSchema}anyType">
 *       <choice>
 *         <element name="xslTransformation" type="{http://schema.webpdf.de/1.0/operation}XslTransformationType"/>
 *         <element name="xRechnung" type="{http://schema.webpdf.de/1.0/operation}XRechnungType"/>
 *       </choice>
 *     </restriction>
 *   </complexContent>
 * </complexType>
 * }</pre>
 * 
 * 
 */
@XmlAccessorType(XmlAccessType.FIELD)
@XmlType(name = "ConverterTransformType", propOrder = {
    "xslTransformation",
    "xRechnung"
})
public class ConverterTransformType {

    protected XslTransformationType xslTransformation;
    protected XRechnungType xRechnung;

    /**
     * Gets the value of the xslTransformation property.
     * 
     * @return
     *     possible object is
     *     {@link XslTransformationType }
     *     
     */
    public XslTransformationType getXslTransformation() {
        return xslTransformation;
    }

    /**
     * Sets the value of the xslTransformation property.
     * 
     * @param value
     *     allowed object is
     *     {@link XslTransformationType }
     *     
     */
    public void setXslTransformation(XslTransformationType value) {
        this.xslTransformation = value;
    }

    public boolean isSetXslTransformation() {
        return (this.xslTransformation!= null);
    }

    /**
     * Gets the value of the xRechnung property.
     * 
     * @return
     *     possible object is
     *     {@link XRechnungType }
     *     
     */
    public XRechnungType getXRechnung() {
        return xRechnung;
    }

    /**
     * Sets the value of the xRechnung property.
     * 
     * @param value
     *     allowed object is
     *     {@link XRechnungType }
     *     
     */
    public void setXRechnung(XRechnungType value) {
        this.xRechnung = value;
    }

    public boolean isSetXRechnung() {
        return (this.xRechnung!= null);
    }

}
